=====
Verge
=====

``verge`` is a job executor inspired by `GNU Parallel
<https://www.gnu.org/software/parallel/>`_, implemented with `Twisted
<https://twistedmatrix.com>`_.


Installation
------------

``pip install verge``

There's a `wheel <http://pythonwheels.com/>`_ built, in case you're into that
(you should be).


Examples
--------

Some useful examples can be found in the GNU Parallel `documentation
<https://www.gnu.org/software/parallel/man.html#https://www.gnu.org/software/parallel/man.html#example__working_as_xargs__n1__argument_appending>`_
Right now ``verge`` doesn't support much, but what it does support should allow
just dropping ``verge`` in everywhere you would have put ``parallel``.
